// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License.
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTOCLink = exports.linkType = exports.styleCodeType = exports.styleCode = exports.styleBold = exports.getLinkMarkdown = exports.bulletItem = exports.getSectionMarkdown = exports.getHeaderMarkdown = exports.defaultValue = exports.type = exports.enumValue = exports.propertyDetails = exports.propertyNameSummary = void 0;
var defined_1 = require("./defined");
var defaultValue_1 = require("./defaultValue");
var enums = require("./enums");
var REFERENCE = "schema-";
function propertyNameSummary(content) {
    return styleBold(content);
}
exports.propertyNameSummary = propertyNameSummary;
function propertyDetails(content) {
    return styleBold(content);
}
exports.propertyDetails = propertyDetails;
function enumValue(enumValue) {
    return styleCode("\"" + enumValue + "\"");
}
exports.enumValue = enumValue;
function type(typeName) {
    // For simplicity, we're re-mapping uri-reference to just be uri
    if (typeName == "uri-reference") {
        typeName = "uri";
    }
    return styleCode(typeName);
}
exports.type = type;
/**
* @function defaultValue
* Format a defaultValue for display in markdown
* @param  {any} value - The default value
* @return {string} The default value styled for display in markdown.
*/
function defaultValue(value) {
    return styleCode(JSON.stringify(value));
}
exports.defaultValue = defaultValue;
/**
* @function getHeaderMarkdown
* Gets the markdown syntax for the start of a header.
* @param  {int} level - The header lever that is being requested
* @return {string} The markdown string that should be placed prior to the title of the header
*/
function getHeaderMarkdown(content, level) {
    level = defaultValue_1.defaultValue(level, 2);
    var md = '';
    for (var i = 0; i < level; ++i) {
        md += '#';
    }
    md += " " + content + "\n\n";
    return md;
}
exports.getHeaderMarkdown = getHeaderMarkdown;
/**
* @function getSectionMarkdown
* Gets the markdown syntax for the start of a section.
* @param  {string} section - The name of the section
* @param  {int} level - The header lever that is being requested
* @return {string} The markdown string that should be placed as the start of the section
*/
function getSectionMarkdown(section, level) {
    var md = '';
    md += '<a name="' + REFERENCE + section.toLowerCase().replace(/ /g, '-') + '"></a>\n';
    md += getHeaderMarkdown(section, level);
    return md;
}
exports.getSectionMarkdown = getSectionMarkdown;
/**
* @function getSectionMarkdown
* Gets the markdown syntax for a bulleted item.
* @param  {string} item - The item being bulleted.
* @param  {int} indentationLevel - The number of indentation levels that should be applied
* @return {string} The markdown string representing the item as a bulleted item at the proper indentation.
*/
function bulletItem(item, indentationLevel) {
    indentationLevel = defaultValue_1.defaultValue(indentationLevel, 0);
    return (' '.repeat(indentationLevel * 3)) + '* ' + item + '\n';
}
exports.bulletItem = bulletItem;
/**
* @function getLinkMarkdown
* Creates a markdown link
* @param  {string} string - The string to be linked
* @param  {string} link - The link that should be applied to the string
* @return {string} The markdown with the specified string hyperlinked to the specified link.
*/
function getLinkMarkdown(string, link) {
    if ((!defined_1.defined(string) || string.length === 0)) {
        return '';
    }
    else if ((!defined_1.defined(link) || link.length === 0)) {
        return string;
    }
    else {
        return '[' + string + '](' + link + ')';
    }
}
exports.getLinkMarkdown = getLinkMarkdown;
/**
* @function styleBold
* Returns back a markdown string that bolds the provided string.
* @param  {string} string - The string to be bolded
* @return {string} The bolded string in markdown syntax
*/
function styleBold(string) {
    if (defined_1.defined(string) && string.length > 0) {
        return '**' + string + '**';
    }
    return '';
}
exports.styleBold = styleBold;
/**
* @function styleCode
* Returns back a markdown string that displays the provided object as code.
* @param  {object} code - The object to be displayed as code. It might be a string, or a number, or ...
* @param  {string} codeLang - The language for the code. If specified will create a tripple back-tip
* @return {string} The code in markdown code syntax
*/
function styleCode(code, codeLang) {
    if (defined_1.defined(code)) {
        // The object might be a string or it might be a number or something else.
        // Let's make sure it's a string first.
        var stringified = code.toString();
        if (stringified.length > 0) {
            if (defined_1.defined(codeLang)) {
                return '```' + codeLang + '\n' + stringified + '```\n';
            }
            else {
                return '`' + stringified + '`';
            }
        }
    }
    return '';
}
exports.styleCode = styleCode;
/**
* @function styleCodeType
* Returns back a markdown string that displays the provided string as code.
* @param  {string} string - The string to be displayed as code
* @param  {string} type - The type of the content in string (if it's a literal string, it will be formatted differently)
* @return {string} The string in markdown code syntax
*/
function styleCodeType(string, type) {
    if (!defined_1.defined(string) || string.length === 0) {
        return '';
    }
    else if (type === 'string') {
        return styleCode('"' + string + '"');
    }
    return styleCode(string);
}
exports.styleCodeType = styleCodeType;
/**
* @function linkType
* Finds any occurrence of type in the provided string, and adds a markdown link to it.
* @param  {string} string - The string that might be referencing a type
* @param  {string} type - The type whose reference within string should be linked.
* @param  {string} autoLink - The enum value indicating how the auto-linking should be handled.
* @return {string} The updated string, with any occurrences of the @type string linked via markdown.
*/
function linkType(string, type, autoLink) {
    if (defaultValue_1.defaultValue(autoLink, enums.autoLinkOption.off) === enums.autoLinkOption.off) {
        return string;
    }
    else if ((!defined_1.defined(string) || string.length === 0)) {
        return string;
    }
    else if ((!defined_1.defined(type) || type.length === 0)) {
        return string;
    }
    else {
        var typeLink = '#' + REFERENCE + type.toLowerCase().replace(/ /g, '-');
        if (autoLink === enums.autoLinkOption.aggressive) {
            var regExp = new RegExp('([^`\.]|^)' + type + '([ \.]|$)');
            return string.replace(regExp, "$1" + getLinkMarkdown(styleCode(type), typeLink) + "$2");
        }
        else {
            var regExp = new RegExp('`' + type + '`');
            return string.replace(regExp, getLinkMarkdown(styleCode(type), typeLink));
        }
    }
}
exports.linkType = linkType;
/**
* @function getTOCLink
* @param  {string} displayString The text to display in the link.
* @param  {string} type          The string to link to.
* @return {string} The markdown for a link with displayString text targeted at type.
*/
function getTOCLink(displayString, type) {
    if ((!defined_1.defined(displayString) || displayString.length === 0)) {
        return displayString;
    }
    else if ((!defined_1.defined(type) || type.length === 0)) {
        return displayString;
    }
    else {
        var typeLink = '#' + REFERENCE + type.toLowerCase().replace(/ /g, '-');
        return getLinkMarkdown(styleCode(displayString), typeLink);
    }
}
exports.getTOCLink = getTOCLink;
//# sourceMappingURL=style.js.map